Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func UniteAxisRanges ¶
UniteAxisRanges sets the range of all axises to the minimum and the maximum of all axises.
Types ¶
type Table ¶
type Table struct {
// RowHeights specifies the number of rows their and relative heights
// E. g.: When {2, 1} are used then the first row will get 66.7% and the
// second row 33.3% of available height.
RowHeights []float64
// ColWidths specifies the number of columns and their relative widths
ColWidths []float64
// PadTop, PadBottom, PadRight, and PadLeft specify the padding
// on the corresponding side of the table.
PadTop, PadBottom, PadRight, PadLeft vg.Length
// PadX and PadY specify the padding between columns and rows
// of tiles respectively..
PadX, PadY vg.Length
}
Table creates a table of subcanvases from a Canvas. In contrast to tiles of gonum.org/v1/plot the columns and rows of a table can have different widths and heights respectively.
Click to show internal directories.
Click to hide internal directories.